# OpenID-federation policy

This is a Python module which allows merging `openid-federation` policies and
applying a given policy to some given metadata. All input and output is in
JSON.

This is being used in [inmor](https://github.com/SUNET/inmor) project.

## License

BSD-2-Clause
